@@ -443,7 +443,7 @@ parse_setup_stationlist (struct pvr_t *pvr)
     return -1;
   }
 
-  if (copycreate_stationlist (&(pvr->stationlist), -1) < 0)
+  if (copycreate_stationlist (&(pvr->stationlist), 0) < 0)
   {
     mp_msg (MSGT_OPEN, MSGL_FATAL,
             "%s No memory allocated for station list, giving up\n",
@@ -1402,6 +1402,7 @@ v4l2_list_capabilities (struct pvr_t *pvr)
 
   /* list available norms */
   vs.index = 0;
+  err = 1;
   mp_msg (MSGT_OPEN, MSGL_INFO, "%s Available norms: ", LOG_LEVEL_V4L2);
   while (ioctl (pvr->dev_fd, VIDIOC_ENUMSTD, &vs) >= 0)
   {
